@@ -11,7 +11,7 @@ from datetime import datetime
 from io import open as io_open
 import logging
 import numpy as np
-from os import chdir, mkdir, path, remove, rename
+from os import mkdir, path, remove, rename
 import pangaea as pa
 from past.builtins import basestring
 from pytz import utc
@@ -66,6 +66,7 @@ def update_hmet_card_file(hmet_card_file_path, new_hmet_data_path):
 
     rename(hmet_card_file_path_temp, hmet_card_file_path)
 
+
 def esat(temp):
     """
     saturation water vapour pressure is expressed with the Teten’s formula
@@ -78,9 +79,10 @@ def esat(temp):
     """
     return 611.21*xu.exp(17.502*(temp-273.16)/(temp-32.19))
 
-#------------------------------------------------------------------------------
+
+# ------------------------------------------------------------------------------
 # MAIN CLASS
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 class GRIDtoGSSHA(object):
     """This class converts the LSM output data to GSSHA formatted input.
 
@@ -110,7 +112,7 @@ class GRIDtoGSSHA(object):
     """
     # DEFAULT GSSHA NetCDF Attributes
     netcdf_attributes = {
-                        'precipitation_rate' :
+                        'precipitation_rate':
                             # NOTE: LSM INFO
                             # units = "kg m-2 s-1" ; i.e. mm s-1
                             {
@@ -126,11 +128,11 @@ class GRIDtoGSSHA(object):
                               'hmet_name' : 'Prcp',
                               'conversion_factor' : {
                                                         'gage': 3600,
-                                                        'ascii' : 3600,
-                                                        'netcdf' : 3600,
+                                                        'ascii': 3600,
+                                                        'netcdf': 3600,
                                                     },
                             },
-                        'precipitation_acc' :
+                        'precipitation_acc':
                             # NOTE: LSM INFO
                             # assumes units = "kg m-2" ; i.e. mm
                             # checks for units: "m"
@@ -146,9 +148,9 @@ class GRIDtoGSSHA(object):
                               'gssha_name': 'precipitation',
                               'hmet_name': 'Prcp',
                               'conversion_factor': {
-                                                        'gage' : 1,
-                                                        'ascii' : 1,
-                                                        'netcdf' : 1,
+                                                        'gage': 1,
+                                                        'ascii': 1,
+                                                        'netcdf': 1,
                                                     },
                             },
                         'precipitation_inc':
@@ -200,8 +202,8 @@ class GRIDtoGSSHA(object):
                               'gssha_name' : 'pressure',
                               'hmet_name' : 'Pres',
                               'conversion_factor' : {
-                                                        'ascii' : 1,
-                                                        'netcdf' : 33.863886667,
+                                                        'ascii': 1,
+                                                        'netcdf': 33.863886667,
                                                     },
                             },
                         'relative_humidity' :
@@ -508,11 +510,13 @@ class GRIDtoGSSHA(object):
         self.lsm_time_dim = lsm_time_dim
         self.output_timezone = output_timezone
         self._xd = None
+
         # load in GSSHA model files
-        chdir(self.gssha_project_folder)
-        sqlalchemy_url, sql_engine = dbt.init_sqlite_memory()
-        db_session = dbt.create_session(sqlalchemy_url, sql_engine)
-        project_manager = ProjectFile()
+        project_manager, db_sessionmaker = \
+            dbt.get_project_session(path.splitext(self.gssha_project_file_name)[0],
+                                    self.gssha_project_folder)
+
+        db_session = db_sessionmaker()
         project_manager.read(directory=self.gssha_project_folder,
                              filename=self.gssha_project_file_name,
                              session=db_session)
@@ -623,7 +627,7 @@ class GRIDtoGSSHA(object):
         if 'radiation' in gssha_var:
             conversion_factor = self.netcdf_attributes[gssha_var]['conversion_factor'][load_type]
             if gssha_var.startswith('direct_radiation') and not isinstance(lsm_var, basestring):
-                #direct_radiation = (1-DIFFUSIVE_FRACION)*global_radiation
+                # direct_radiation = (1-DIFFUSIVE_FRACION)*global_radiation
                 global_radiation_var, diffusive_fraction_var = lsm_var
                 global_radiation = self._load_lsm_data(global_radiation_var, conversion_factor)
                 diffusive_fraction = self._load_lsm_data(diffusive_fraction_var)
@@ -633,7 +637,7 @@ class GRIDtoGSSHA(object):
                 self.data = ((1-diffusive_fraction)*global_radiation)
 
             elif gssha_var.startswith('diffusive_radiation') and not isinstance(lsm_var, basestring):
-                #diffusive_radiation = DIFFUSIVE_FRACION*global_radiation
+                # diffusive_radiation = DIFFUSIVE_FRACION*global_radiation
                 global_radiation_var, diffusive_fraction_var = lsm_var
                 global_radiation = self._load_lsm_data(global_radiation_var, conversion_factor)
                 diffusive_fraction = self._load_lsm_data(diffusive_fraction_var)
@@ -702,26 +706,28 @@ class GRIDtoGSSHA(object):
             if conversion_function:
                 self.data.values = self.netcdf_attributes[gssha_var]['conversion_function'][load_type](self.data.values)
 
-        if load_type == 'ascii' or load_type == 'netcdf':
-            # CONVERT TO INCREMENTAL
-            if gssha_var == 'precipitation_acc':
-                self.data.values = np.lib.pad(self.data.diff(self.lsm_time_dim).values,
-                                              ((1,0),(0,0),(0,0)),
-                                              'constant',
-                                              constant_values=0)
-
-            # CONVERT PRECIP TO RADAR (mm/hr) IN FILE
-            if gssha_var == 'precipitation_inc' or gssha_var == 'precipitation_acc':
-                # convert from mm to mm/hr
-                time_step_hours = np.diff(self.xd[self.lsm_time_var].values)[0]/np.timedelta64(1, 'h')
-                self.data.values /= time_step_hours
-
-        if 'precipitation' in gssha_var and not isinstance(lsm_var, str):
+        if 'precipitation' in gssha_var:
+            # NOTE: Precipitation is converted from mm/s to mm/hr
+            # with the conversion factor when it is a rate.
             if 'units' in self.data.attrs:
                 if self.data.attrs['units'] == 'm':
                     # convert from m to mm
                     self.data.values *= 1000
 
+            if load_type == 'ascii' or load_type == 'netcdf':
+                # CONVERT TO INCREMENTAL
+                if gssha_var == 'precipitation_acc':
+                    self.data.values = np.lib.pad(self.data.diff(self.lsm_time_dim).values,
+                                                  ((1, 0), (0, 0), (0, 0)),
+                                                  'constant',
+                                                  constant_values=0)
+
+                # CONVERT PRECIP TO RADAR (mm/hr) IN FILE
+                if gssha_var == 'precipitation_inc' or gssha_var == 'precipitation_acc':
+                    # convert from mm to mm/hr
+                    time_step_hours = np.diff(self.xd[self.lsm_time_var].values)[0]/np.timedelta64(1, 'h')
+                    self.data.values /= time_step_hours
+
         # convert to dataset
         gssha_data_var_name = self.netcdf_attributes[gssha_var]['gssha_name']
         self.data = self.data.to_dataset(name=gssha_data_var_name)
